# PoserToOctane Plugin Defaults
# 
# Copyright (c) 2012, Paul Kinnane, Physicalc Software Pty Ptd
#
# For additional support, contact Paul Kinnane at support@physicalc-software.com
#
# Version 1.0 - original release
#
#========================================================================================================================================

### IMPORANT : Reload a scene or start a new scene in order for these defaults to be refreshed in Poser

# The maximum scene size that will load into the plugin.  Increase that if you have high-end equipment.  Increase this figure at your own risk!
# As a rule, if your PC has 4Gig RAM, the practical scene size limit with be 4Mil polygons
MAX_NUMBER_OF_SCENE_POLYGONS = 4000000 


MAX_NUMBER_OF_RGBA_TEXTURES = 64 # This is the maximum number of LDR "image" and "alphaimage" textures that your video card can store.
MAX_NUMBER_OF_GRAYSCALE_TEXTURES = 32 # This is the maximum number LDR of "floatimage" textures that your video card can store.
MAX_NUMBER_OF_HDR_RGBA_TEXTURES = 4 # This is the maximum number of HDR "image" and "alphaimage" textures that your video card can store.
MAX_NUMBER_OF_HDR_GRAYSCALE_TEXTURES = 4 # This is the maximum number of HDR "floatimage" textures that your video card can store.  

REFRESH_DEFAULT = 200 # The default Viewport refresh rate

POSER_TO_OCTANE_SCALE_FACTOR = 2.62128 # This converts the geometry from poser units to metres.

# Kernel defaults
DEFAULT_KERNEL = "pathtracing" # Opions are "pmc", "directlighting", "pathtracing", "deep_channel_kernel"
DEFAULT_RAYEPSILON = 0.00001
DEFAULT_MAXDEPTH = 12 
DEFAULT_MAXSAMPLES = 12000
DEFAULT_FILTERSIZE = 1.5

# Imager defaults
DEFAULT_EXPOSURE = 1
DEFAULT_GAMMA = 1
DEFAULT_CAMERA_RESPONSE = "Agfacolor HDC 100 plusCD" # Case sensitive
DEFAULT_VIGNETTING = 0.3
DEFAULT_MIN_DISPLAY_SAMPLES = 1

# Camera defaults
DEFAULT_APERTURE = 1
DEFAULT_NEARCLIPDEPTH = 0.0001 # Should be 0.048 * POSER_TO_OCTANE_SCALE_FACTOR in order to match the default Poser camera hither, but this causes an issue with RC2 of Octane for focus picking

# Resolution defaults
DEFAULT_RESOLUTION_WIDTH = 800 # Set to 0 to use the Poser Render Resolution width
DEFAULT_RESOLUTION_HEIGHT = 600 # Set to 0 to use the Poser Render Resolution height

# Window starting coordinate positions
OPTIONS_WINDOW_X_DEFAULT = 800
OPTIONS_WINDOW_Y_DEFAULT = 100
RENDER_WINDOW_X_DEFAULT = 200
RENDER_WINDOW_Y_DEFAULT = 200
MATERIALDB_WINDOW_X_DEFAULT = 200
MATERIALDB_WINDOW_Y_DEFAULT = 200

# Material conversion defaults
GLOSSY_DIFFUSE_RATIO = 0.2 # If total glossy color * value * GLOSSY_DIFFUSE_RATIO is greater than total diffuse color * value, then make the node glossy, otherwise diffuse
# Set the above to 0 to force all materials to be glossy (and not diffuse)

GLOSSY_SPECULAR = 0.05 # The specular value for glossy materials converted from Poser
GLOSSY_ROUGHNESS = 0.7 # The roughness value for glossy materials converted from Poser
GLOSSY_BUMP_POWER = 0.05 # The bump value for glossy materials converted from Poser.  Only applied if there is a bump map

GLOSSY_POWER_PERCENT = 0.2 # Depreciated
SKIN_SPECULAR_POWER = 0.005 # Depreciated
SKIN_SPECULAR_ROUGHNESS = 0.5 # Depreciated

DEFAULT_IMAGE_POWER = 1

USE_TEXTURE_EMISSION_FOR_EMITTERS = 1 # Set to 0 to set emission = "blackbody" for ambient materials, or 1 for "texture emission".  If 1, then the ambient_color from the Poser material will be used as the emitter color

MATERIAL_IMPORT_EXPORT_DEFAULT_FOLDER = "" # "" defaults to the Poser Temp Files (set in the Misc tab of the General Preferences)
# For example, you can set to a specific folder as follows.....MATERIAL_IMPORT_EXPORT_DEFAULT_FOLDER = "C:\\Users\\Public\\Documents"

ANIMATION_OUTPUT_DEFAULT_FOLDER = "" # "" defaults to the Poser Temp Files (set in the Misc tab of the General Preferences)
# For example, you can set to a specific folder as follows.....ANIMATION_OUTPUT_DEFAULT_FOLDER = "C:\\Users\\Public\\Documents"

PROGRESSIVE_SAVE_OUTPUT_FOLDER = "" # "" defaults to the Poser Temp Files (set in the Misc tab of the General Preferences)
# For example, you can set to a specific folder as follows.....PROGRESSIVE_SAVE_OUTPUT_DEFAULT_FOLDER = "C:\\Users\\Public\\Documents"
PROGRESSIVE_SAVE_SAMPLES_INTERVAL = 500 # The number of samples between progressive save images

SkinNodeTemplate = [ # Always glossy
    ["diffuse", "power", 1.0],
    ["diffuse", "gamma", 2.2],
    ["specular", [0.0, 0.025, 0.05]], # Must be 3 floats = color
    ["roughness", 0.5],
    ["filmwidth", 1.0],
    ["bump", "power", 0.05],
    ["bump", "gamma", 1.0]
]


# Skin materials in the list below default to glossy.  Must be lowercase
SkinMaterials = [
    "skin",
    "skinbody", 
    "skintorso", 
    "skinneck", 
    "skinhip", 
    "skinfeet", 
    "skinleg", 
    "skinforearm", 
    "skinarm",  
    "skinhand", 
    "skinhead", 
    "skinscalp", 
    "skinlips", 
    "skinknee", 
    "skinshin", 
    "skinthigh", 
    "nipples", 
    "lips", 
    "eyesocket", 
    "nostrils", 
    "head", 
    "body", 
    "legs",
    "arms",
    "skin_body", 
    "skin_head", 
    "skin_legs",
    "skin_arms",
    "1_skinface", 
    "1_nostril", 
    "1_lip", 
    "2_skinhead", 
    "2_skinneck", 
    "2_skintorso", 
    "2_nipple", 
    "2_skinhip", 
    "3_skinarm", 
    "3_skinfoot", 
    "3_skinforearm", 
    "3_skinhand", 
    "3_skinleg", 
    "teeth",
    "tongue",
    "innermouth",
    "mouthinner"
    "gen_skin", 
    "genitals", 
    "foreskin",
    "lacrimals",
    "nailsfingers",
    "nailstoes"
]

PinIgnoreList = [
    "thinlens_fov",
    "thinlens_pos",
    "thinlens_target",
    "thinlens_up",
    
]

        